@@ -29,32 +29,64 @@ struct _EogScrollViewClass {
 	void (* zoom_changed) (EogScrollView *view, double zoom);
 };
 
+/**
+ * EogTransparencyStyle:
+ * @EOG_TRANSP_BACKGROUND: Use the background color of the current UI theme
+ * @EOG_TRANSP_CHECKED: Show transparent parts as a checkerboard pattern
+ * @EOG_TRANSP_COLOR: Show transparent parts in a user defined color
+ *                    (see #EogScrollView:transparency-color )
+ *
+ * Used to define how transparent image parts are drawn.
+ */
 typedef enum {
 	EOG_TRANSP_BACKGROUND,
 	EOG_TRANSP_CHECKED,
 	EOG_TRANSP_COLOR
 } EogTransparencyStyle;
 
+/**
+ * EogZoomMode:
+ * @EOG_ZOOM_MODE_FREE: Use the currently set zoom factor to display the image
+ *                      (see eog_scroll_view_set_zoom()).
+ * @EOG_ZOOM_MODE_SHRINK_TO_FIT: If an image is to large for the window,
+ *                               zoom out until the image is fully visible.
+ *                               This will never zoom in on smaller images.
+ *
+ * Used to determine the zooming behaviour of an #EogScrollView.
+ */
+typedef enum {
+	EOG_ZOOM_MODE_FREE,
+	EOG_ZOOM_MODE_SHRINK_TO_FIT
+} EogZoomMode;
+
 GType    eog_scroll_view_get_type         (void) G_GNUC_CONST;
 GtkWidget* eog_scroll_view_new            (void);
 
 /* loading stuff */
 void     eog_scroll_view_set_image        (EogScrollView *view, EogImage *image);
+EogImage* eog_scroll_view_get_image       (EogScrollView *view);
+
 
 /* general properties */
 void     eog_scroll_view_set_scroll_wheel_zoom (EogScrollView *view, gboolean scroll_wheel_zoom);
 void     eog_scroll_view_set_zoom_upscale (EogScrollView *view, gboolean upscale);
 void     eog_scroll_view_set_zoom_multiplier (EogScrollView *view, gdouble multiplier);
-void     eog_scroll_view_set_antialiasing (EogScrollView *view, gboolean state);
-void     eog_scroll_view_set_transparency (EogScrollView *view, EogTransparencyStyle style, GdkColor *color);
+void	eog_scroll_view_set_zoom_mode (EogScrollView *view, EogZoomMode mode);
+EogZoomMode	eog_scroll_view_get_zoom_mode (EogScrollView *view);
+void     eog_scroll_view_set_antialiasing_in (EogScrollView *view, gboolean state);
+void     eog_scroll_view_set_antialiasing_out (EogScrollView *view, gboolean state);
+void	eog_scroll_view_set_transparency_color (EogScrollView *view, GdkColor *color);
+void     eog_scroll_view_set_transparency (EogScrollView *view, EogTransparencyStyle style);
 gboolean eog_scroll_view_scrollbars_visible (EogScrollView *view);
 void	 eog_scroll_view_set_popup (EogScrollView *view, GtkMenu *menu);
-void	 eog_scroll_view_set_bg_color (EogScrollView *view, GdkColor *color);
-
+void	 eog_scroll_view_set_background_color (EogScrollView *view,
+					       const GdkColor *color);
+void	 eog_scroll_view_override_bg_color (EogScrollView *view,
+					    const GdkColor *color);
+void     eog_scroll_view_set_use_bg_color (EogScrollView *view, gboolean use);
 /* zoom api */
 void     eog_scroll_view_zoom_in          (EogScrollView *view, gboolean smooth);
 void     eog_scroll_view_zoom_out         (EogScrollView *view, gboolean smooth);
-void     eog_scroll_view_zoom_fit         (EogScrollView *view);
 void     eog_scroll_view_set_zoom         (EogScrollView *view, double zoom);
 double   eog_scroll_view_get_zoom         (EogScrollView *view);
 gboolean eog_scroll_view_get_zoom_is_min  (EogScrollView *view);
